BonfireCollisionConfigQuadTree class

Inheritance

Constructors

BonfireCollisionConfigQuadTree({double? minimumDistance, int maxObjects = 25, int maxLevels = 10})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxLevels → int
final
maxObjects → int
final
minimumDistance → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<T>({required T defaultCollision(BonfireCollisionConfigDefault), required T quadTreeCollision(BonfireCollisionConfigQuadTree)}) → T
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited