BInterval class

Inheritance

Constructors

BInterval({required Behavior doBehavior, required int interval, dynamic id})

Properties

doBehavior → Behavior
final
hashCode → int
The hash code for this object.
no setterinherited
id → dynamic
finalinherited
interval → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(double dt, GameComponent comp, BonfireGameInterface game) → bool
Processes this behavior for the current frame.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited