process method
Processes this behavior for the current frame.
Returns true when the behavior is finished and the manager should
advance to the next behavior, or false to keep running it on the next
frame.
Implementation
@override
bool process(double dt, GameComponent comp, BonfireGameInterface game) {
var allFinished = true;
for (final behavior in behaviors) {
if (!behavior.process(dt, comp, game)) {
allFinished = false;
}
}
return allFinished;
}