debugBehaviors property
When true, prints a log every time the current behavior changes.
Useful to debug your AI. Set it before the component is mounted
(e.g. in the constructor).
Implementation
bool debugBehaviors = false;
When true, prints a log every time the current behavior changes.
Useful to debug your AI. Set it before the component is mounted
(e.g. in the constructor).
bool debugBehaviors = false;