CollisionApi class

Constructors

CollisionApi(Movement comp)

Properties

bodyType BodyType
getter/setter pair
comp Movement
final
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
no setter
lastCollisionData CollisionData?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

blockMovementHandle(Set<Vector2> intersectionPoints, GameComponent other) bool
disable() → void
dispose() → void
enable() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBlockMovementListener(BlockMovementCallback callback) → void
onCollision(Set<Vector2> intersectionPoints, PositionComponent other) → void
onMovementBlockedListener(MovementBlockedCallback callback) → void
reflectionResolution(ReflectionResolutionCallback callback) → void
setCollisionResolution(WithCollision other, CollisionData data) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited