GlobalForcesSettings class

Constructors

GlobalForcesSettings({Vector2? gravity, Vector2? wind, Vector2? friction, double? dragCoefficient = 0.01})

Properties

dragCoefficient double?
final
friction Vector2?
final
gravity Vector2?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wind Vector2?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited