PinchEvent class

Constructors

PinchEvent({required double initalDistance, required double initalAngle, required Vector2 initalCenter, required double distance, required double angle, required Vector2 center, required FingerPoint finger1, required FingerPoint finger2})
PinchEvent.fromFingers(FingerPoint f1, FingerPoint f2)
factory

Properties

angle → double
final
center → Vector2
final
diffAngle → double
no setter
diffCenter → Vector2
no setter
diffDistance → double
no setter
distance → double
final
factorAngle → double
no setter
factorDistance → double
no setter
finger1 → FingerPoint
final
finger2 → FingerPoint
final
hashCode → int
The hash code for this object.
no setterinherited
initalAngle → double
final
initalCenter → Vector2
final
initalDistance → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited