KeyboardDirectionalKeys class

Constructors

KeyboardDirectionalKeys({required LogicalKeyboardKey up, required LogicalKeyboardKey down, required LogicalKeyboardKey left, required LogicalKeyboardKey right})
KeyboardDirectionalKeys.arrows()
factory
KeyboardDirectionalKeys.wasd()
factory

Properties

down → LogicalKeyboardKey
final
hashCode → int
The hash code for this object.
no setterinherited
keys → List<LogicalKeyboardKey>
no setter
left → LogicalKeyboardKey
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
up → LogicalKeyboardKey
final

Methods

contain(LogicalKeyboardKey key) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited