JoystickMapExplorer class

Mixed-in types

Constructors

JoystickMapExplorer(BonfireCamera camera)

Properties

camera → BonfireCamera
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onJoystickAction(JoystickActionEvent event) → void
override
onJoystickChangeDirectional(JoystickDirectionalEvent event) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited