renderPriorityOffsetY property

double get renderPriorityOffsetY

Pixels added to the Y priority of game components so they keep rendering above the tile map when the world extends to negative coordinates. Defaults to 0 for regular maps (origin at 0+).

Implementation

double get renderPriorityOffsetY => 0;