MapTerrainCorners class

Inheritance

Constructors

MapTerrainCorners({required double value, required double? to, required TerrainSpriteSheet spriteSheet, String? type, Map<String, dynamic>? properties, List<ShapeHitbox>? collisionsBuilder()?})

Properties

collisionOnlyCloseCorners → bool
finalinherited
collisionsBuilder → List<ShapeHitbox>? Function()?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
maxRandomValue → int
no setterinherited
properties → Map<String, dynamic>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sprites → List<TileSprite>
finalinherited
spriteSheet → TerrainSpriteSheet
final
spritesProportion → List<double>
finalinherited
to → double?
final
type → String?
finalinherited
value → double
finalinherited

Methods

getCollisionClone({bool checkOnlyClose = false}) → List<ShapeHitbox>?
inherited
getSingleSprite() → TileSprite?
inherited
inRange(int value) → int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited