SpritefusionMapLayerTile class

Constructors

SpritefusionMapLayerTile({required String id, required int x, required int y})
SpritefusionMapLayerTile.fromJson(String source)
factory
SpritefusionMapLayerTile.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
final
idInt → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → int
final
y → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited