TiledObjectProperties class

Constructors

TiledObjectProperties(Vector2 position, Vector2 size, String? type, double? rotation, Map<String, dynamic> others, String? name, int? id, ShapeHitbox area)

Properties

area → ShapeHitbox
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
name → String?
final
others → Map<String, dynamic>
final
position → Vector2
final
rotation → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Vector2
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited