mapChildren property

List<GameComponent>? mapChildren
final

Decorations that must render as children of the tile map (e.g. oversized tiles from Tiled whose stacking must follow the layer order instead of the dynamic Y-sort used by game-level components).

Implementation

final List<GameComponent>? mapChildren;