AssetsLoaderApi class

API that handles loading assets during the component lifecycle.

The parent component must be a Component.

Constructors

AssetsLoaderApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(AssetToLoad asset) → void
load() Future<void>
Loads all registered assets. Should be called during onLoad.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited