DirectionAnimationApi class
API for managing movement direction animations.
Constructors
- DirectionAnimationApi(Movement _comp)
Properties
- animation ↔ SimpleDirectionAnimation?
-
getter/setter pair
- animationScale → Vector2
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canExecuteAnimation(
DirectionAnimationMethod method) → bool -
clearAnimationExecutionListeners(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAnimationExecutionListener(
DirectionAnimationExecutionListener callback) → void -
onLoad(
BonfireGameInterface gameRef) → Future< void> -
onPlayIdleDownAnimation(
) → void -
onPlayIdleDownLeftAnimation(
) → void -
onPlayIdleDownRightAnimation(
) → void -
onPlayIdleLeftAnimation(
) → void -
onPlayIdleRightAnimation(
) → void -
onPlayIdleUpAnimation(
) → void -
onPlayIdleUpLeftAnimation(
) → void -
onPlayIdleUpRightAnimation(
) → void -
onPlayRunDownAnimation(
) → void -
onPlayRunDownLeftAnimation(
) → void -
onPlayRunDownRightAnimation(
) → void -
onPlayRunLeftAnimation(
) → void -
onPlayRunRightAnimation(
) → void -
onPlayRunUpAnimation(
) → void -
onPlayRunUpLeftAnimation(
) → void -
onPlayRunUpRightAnimation(
) → void -
play(
SimpleAnimationEnum animationType) → void -
playIdleAnimation(
) → void -
removeAnimationExecutionListener(
DirectionAnimationExecutionListener callback) → void -
render(
Canvas canvas, Paint paint) → void -
replaceAnimation(
SimpleDirectionAnimation newAnimation, {bool doIdle = false, VoidCallback? idleCallback}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
update(
double dt) → void -
updateAnimation(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited