FlipRenderApi class

API that handles render flipping for a component.

Constructors

FlipRenderApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
horizontally bool
no setter
isFlipped bool
no setter
isFlippedHorizontally bool
no setter
isFlippedVertically bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertically bool
no setter

Methods

flipHorizontally() → void
flipVertically() → void
Applies the flip transform to the canvas.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited