isMoving property
bool
get
isMoving
Whether the component is currently moving along a path.
Implementation
bool get isMoving => _currentPath.isNotEmpty;
Whether the component is currently moving along a path.
bool get isMoving => _currentPath.isNotEmpty;