mixins/pushable/pushable_api library

Classes

PushableApi
API that handles pushable behavior for a component.

Enums

PushableFromEnum
Defines from which type of component the push can happen.

Typedefs

OnPushCallback = bool Function(GameComponent component)
Callback used to decide if the component accepts being pushed by component.