mixins/random_movement/random_movement library

Classes

RandomMovementApi
API responsible for adding random movement behavior to a component.
RandomMovementDirections
Defines which directions are allowed for random movement.

Mixins

WithRandomMovement
Mixin responsible for adding random movement to a component.

Typedefs

OnRandomMovementStartCallback = void Function(Direction direction)
Callback fired when random movement starts.
OnRandomMovementStopCallback = void Function()
Callback fired when random movement stops.