onCollisionEnd method
onCollisionEnd is called once when this object has stopped colliding
with other.
Implementation
@override
void onCollisionEnd(PositionComponent other) {
sensor.handleCollisionEnd(other);
super.onCollisionEnd(other);
}
onCollisionEnd is called once when this object has stopped colliding
with other.
@override
void onCollisionEnd(PositionComponent other) {
sensor.handleCollisionEnd(other);
super.onCollisionEnd(other);
}