SensorApi<T extends GameComponent> class

API for managing sensor behavior.

This class encapsulates contact detection interval, enabled state, and collision handling callbacks.

Constructors

SensorApi(GameComponent _comp)

Properties

enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interval int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Clean up all listeners.
ensureCollisionShape() Future<void>
handleCollision(PositionComponent other) → void
handleCollisionEnd(PositionComponent other) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onContactEndListener(SensorContactCallback<T> callback) → void
Register callback fired when contact ends.
onContactListener(SensorContactCallback<T> callback) → void
Register callback fired while contact is detected.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited