IntervalTick class
Constructors
- IntervalTick(int interval, {VoidCallback? onTick, bool tickFirstUpdate = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTick → VoidCallback?
-
final
- running → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tickFirstUpdate ↔ bool
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → void -
play(
) → void -
reset(
) → void -
tick(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
double dt) → bool -
updateInterval(
int interval) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited