behavior/behavior library
Classes
- BAction
- BCanSee
-
BCanSeeType<
T extends GameComponent> - BCondition
- BCustom
- Behavior
- Base class of a behavior.
- BehaviorManager
-
Manages the execution of a list of Behaviors, processing one per frame and
advancing to the next one whenever the current behavior returns
truefrom Behavior.process. - BInterval
- BList
- BMoveToComponent
- BOnce
-
Runs action only once for the lifetime of this instance and then is
considered finished (returns
truefrom then on). - BParallel
- Runs all its children in parallel, every frame.
- BRandomMovement
- BSeeAndMoveToTarget
- BSeeAndPositioned
- BSelector
-
Runs its children in priority order and picks the first one that is
active (returns
falsefrom Behavior.process).
Mixins
- UseBehavior
-
Adds a behavior system to a GameComponent, allowing you to program the
component AI declaratively — without filling
update()withifs.