ElasticCollisionApi class
- Available extensions
Constructors
Properties
- comp → WithCollision
-
final
- enabled → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- restitution → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disable(
) → void -
dispose(
) → void -
enable(
) → void -
makeBasketball(
) → void -
Available on ElasticCollisionApi, provided by the BounceBehaviors extension
Make object bounce like a basketball -
makeDroppedBall(
) → void -
Available on ElasticCollisionApi, provided by the BounceBehaviors extension
Make object bounce and gradually lose energy (like a dropped ball) -
makeEternalBounce(
) → void -
Available on ElasticCollisionApi, provided by the BounceBehaviors extension
Make object bounce eternally (near-perfect elasticity) -
makeHeavyObject(
) → void -
Available on ElasticCollisionApi, provided by the BounceBehaviors extension
Make object barely bounce (like a heavy object) -
makePingPongBall(
) → void -
Available on ElasticCollisionApi, provided by the BounceBehaviors extension
Make object bounce like a ping pong ball -
makeRubberBall(
) → void -
Available on ElasticCollisionApi, provided by the BounceBehaviors extension
Make object bounce like a rubber ball -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onBounceListener(
OnBounceCallback callback) → void -
setup(
{double? bounciness, double? minBounceVelocity}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited