Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
getCollisionShapeHitbox(Iterable<ShapeHitbox> shapeHitboxes, Set<Vector2> intersectionPoints)
→ ShapeHitbox?
-
-
intersectCirclePolygon(ShapeHitbox shapeA, CircleHitbox shapeB, PositionComponent other, {bool inverted = false})
→ ({double depth, Vector2 normal})
-
-
intersectCircles(CircleHitbox shapeA, CircleHitbox shapeB)
→ ({double depth, Vector2 normal})
-
-
intersectPolygons(ShapeHitbox shapeA, ShapeHitbox shapeB, PositionComponent other)
→ ({double depth, Vector2 normal})
-