mixins/assets_loader/assets_loader_api library
Classes
-
AssetsLoader<
T> - Utility to load a list of assets and clear callbacks afterwards.
- AssetsLoaderApi
- API that handles loading assets during the component lifecycle.
-
AssetToLoad<
T> - Represents an asset that will be loaded and its callback called.