PushableApi class
API that handles pushable behavior for a component.
To use this behavior the parent component must have a Movement mixin.
Constructors
- PushableApi(Movement _comp)
Properties
Methods
-
dispose(
) → void - Releases the registered push listener.
-
handleCollision(
Set< Vector2> intersectionPoints, PositionComponent other) → void - Handles collision from another component and applies push if needed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPushListener(
OnPushCallback callback) → void - Registers a callback that decides if the component can be pushed.
-
setup(
{bool? enabled, PushableFromEnum? pushableFrom, bool? pushPerCellEnabled, Vector2? cellSize, double? pushPerCellDuration, Curve? pushPerCellCurve}) → void - Sets up pushable behavior.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited