TileRecognizerApi class
API for querying map tile information below the component.
Constructors
- TileRecognizerApi(GameComponent _comp)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tileListBelow(
) → Iterable< TileComponent> - Returns all tile components below the component.
-
tilePropertiesBelow(
) → Map< String, dynamic> ? - Returns the properties of the first map tile below the component.
-
tilePropertiesListBelow(
) → List< Map< ?String, dynamic> > - Returns all tile properties below the component.
-
tileTypeBelow(
) → String? - Returns the type of the first map tile below the component.
-
tileTypeListBelow(
) → List< String> - Returns all tile types below the component.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited